package client;

import java.awt.event.*;
import java.applet.Applet;

import tictactoe.RemoteGame;
import tictactoe.Move;
import tictactoe.AssertionException;

/**
 * This class picks up mouse clicks and propogates them
 * to a Player of the BoardGame.
 * <P>
 * <B>To do:</B>
 * Implement better feedback.
 *
 * @see Place
 *
 * @author Oscar.Nierstrasz@acm.org
 * @version 2.1 1999-03-31
 */
public class PlaceListener extends MouseAdapter {
	private final Place _place;
	private final GameView _view;
	
	public PlaceListener(Place place, GameView view) {
		_place = place;
		_view = view;
	}

	/**
	 * When the mouse is clicked, we ask the current player to
	 * make the corresponding move.  Report when the game is over.
	 */
	public void mouseClicked(MouseEvent e) {
		RemoteGame game = _view.game();
		int col = _place.col();
		int row = _place.row();
		if (game.ready()) {
			if (game.notOver()) {
				try {
					game.remoteMove(new Move(col,row, _view.mark()));
				} catch (AssertionException err) {
					_view.showFeedBack("Invalid move! -- "
						+ game.currentPlayer().mark() + " plays");
				}
			} else {
				_view.showFeedBack("The game is over!");
			}
		} else {
				_view.showFeedBack("Please wait for a second Player!");
		}
	}
}
